==========
Core Tests
==========

Basic
=====

.. automodule:: test_basic
    :members:
    :show-inheritance:

Consistency
===========

.. automodule:: test_consistency
    :members:
    :show-inheritance:

Biomass
=======

.. automodule:: test_biomass
    :members:
    :show-inheritance:

Annotation
==========

.. automodule:: test_annotation
    :members:
    :show-inheritance:

Syntax
======

.. automodule:: test_syntax
    :members:
    :show-inheritance:
